@@ -5,10 +5,10 @@ describe 'cinder::backend::emc_vnx' do
 
   let :req_params do
     {
-      :san_ip                => '127.0.0.2',
-      :san_login             => 'emc',
-      :san_password          => 'password',
-      :storage_vnx_pool_name => 'emc-storage-pool'
+      :san_ip                   => '127.0.0.2',
+      :san_login                => 'emc',
+      :san_password             => 'password',
+      :storage_vnx_pool_names   => 'emc-storage-pool'
     }
   end
 
@@ -26,8 +26,8 @@ describe 'cinder::backend::emc_vnx' do
       is_expected.to contain_cinder_config('emc/storage_protocol').with_value('iscsi')
       is_expected.to contain_cinder_config('emc/san_ip').with_value('127.0.0.2')
       is_expected.to contain_cinder_config('emc/san_login').with_value('emc')
-      is_expected.to contain_cinder_config('emc/san_password').with_value('password')
-      is_expected.to contain_cinder_config('emc/storage_vnx_pool_name').with_value('emc-storage-pool')
+      is_expected.to contain_cinder_config('emc/san_password').with_value('password').with_secret(true)
+      is_expected.to contain_cinder_config('emc/storage_vnx_pool_names').with_value('emc-storage-pool')
       is_expected.to contain_cinder_config('emc/initiator_auto_registration').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_cinder_config('emc/storage_vnx_authentication_type').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_cinder_config('emc/storage_vnx_security_file_dir').with_value('<SERVICE DEFAULT>')
